macro_rules! malloc {
($a:ty, $n:expr) => { ... };
}Available on non-crate feature
lock only.Expand description
Allocate for a given type and number of elements.
macro_rules! malloc {
($a:ty, $n:expr) => { ... };
}lock only.Allocate for a given type and number of elements.