pub struct SpiceLock { /* private fields */ }Expand description
A wrapper singleton struct around the API to prevent concurrent calls to SPICE functions from multiple threads.
Exposes all functions as methods with identical signatures besides the added &self argument.
Only available with the lock feature enabled.
Implementations
sourceimpl SpiceLock
impl SpiceLock
sourcepub fn try_acquire() -> Result<Self, &'static str>
pub fn try_acquire() -> Result<Self, &'static str>
Attempt to create a SpiceLock instance.
Will be Err if an instance already exists.
sourceimpl SpiceLock
impl SpiceLock
sourcepub fn illumf(
&self,
method: &str,
target: &str,
ilusrc: &str,
et: f64,
fixref: &str,
abcorr: &str,
obsrvr: &str,
spoint: [f64; 3]
) -> (f64, [f64; 3], f64, f64, f64, bool, bool)
pub fn illumf( &self, method: &str, target: &str, ilusrc: &str, et: f64, fixref: &str, abcorr: &str, obsrvr: &str, spoint: [f64; 3] ) -> (f64, [f64; 3], f64, f64, f64, bool, bool)
Compute the illumination angles—phase, incidence, and emission—at a specified point on a target body. Return logical flags indicating whether the surface point is visible from the observer’s position and whether the surface point is illuminated.
The target body’s surface is represented using topographic data provided by DSK files, or by a reference ellipsoid.
The illumination source is a specified ephemeris object.
sourceimpl SpiceLock
impl SpiceLock
sourcepub fn occult(
&self,
targ1: &str,
shape1: &str,
frame1: &str,
targ2: &str,
shape2: &str,
frame2: &str,
abcorr: &str,
obsrvr: &str,
et: f64
) -> i32
pub fn occult( &self, targ1: &str, shape1: &str, frame1: &str, targ2: &str, shape2: &str, frame2: &str, abcorr: &str, obsrvr: &str, et: f64 ) -> i32
Determines the occultation condition (not occulted, partially, etc.) of one target relative to another target as seen by an observer at a given time, with targets modeled as points, ellipsoids, or digital shapes (DSK)